#ifndef __KPMAINWIDGET_H
#define __KPMAINWIDGET_H

#include <qsplitter.h>
#include "bitmaplist.h"
#include <qlist.h>
#include <qcolor.h>

class KPBitmapWidget;

class KPMainWidget : public QSplitter
{
    Q_OBJECT
public:
    KPMainWidget(QWidget *parent=0, const char *name=0);
    void load(const QString &str);
public slots:
    void slotReset();
    void slotSaveCurrentBitmap();
    void slotSaveAllBitmaps();
    void slotSaveCHeader();
    void slotSavePointArray();
    void slotLoad();
    void slotIncreaseScale();
    void slotDecreaseScale();
signals:
    void message(const QString &msg);
protected:
    KPBitmapWidget *bmpWidget;
    KPBitmapList *bmpList;

};


#endif
